==> wrogue-0.7.4.tar.bz2: wrogue-0.7.4/src/be_stub.c <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * stub back-end
 */


#define Uses_Game
#define Uses_Util
#include "mheader.h"

#include "be.h"


/*
 * IO init
 */
void io_init(void)
{

}



/*
 * IO clean up
 */
void io_clean_up(void)
{

}



/*
 * updates the screen
 */
void update_screen(void)
{

}



/*
 * clears the screen
 */
void clear_screen(void)
{

}



/*
 * places the cursor at the specified location
 */
void place_cursor_at(SCREEN_COORD y, SCREEN_COORD x)
{

	NOT_USED(y);
	NOT_USED(x);
}



/*
 * returns the current Y coordinate of the cursor
 */
SCREEN_COORD cursor_y(void)
{
	return 0;
}



/*
 * returns the current X coordinate of the cursor
 */
SCREEN_COORD cursor_x(void)
{

	return 0;
}



/*
 * renders the cursor at its current position
 */
void render_cursor(COLOR color)
{

	NOT_USED(color);
}



/*
 * renders a character at the current cursor position
 */
void render_char(COLOR color, SYMBOL ch)
{

	NOT_USED(color);
	NOT_USED(ch);
}



/*
 * renders a character at the specified position
 */
void render_char_at(COLOR color, SCREEN_COORD y, SCREEN_COORD x, SYMBOL c)
{

	NOT_USED(color);
	NOT_USED(y);
	NOT_USED(x);
	NOT_USED(c);
}



/*
 * get key
 */
KEY_CODE lowlevel_get_key(void)
{

	return 0;
}



/*
 * clears a section of the screen for text display
 */
void clear_text_window(SCREEN_COORD y1, SCREEN_COORD x1, SCREEN_COORD y2, SCREEN_COORD x2)
{

	NOT_USED(y1);
	NOT_USED(x1);
	NOT_USED(y2);
	NOT_USED(x2);
}



/*
 * renders the background
 */
void render_background(void)
{

}



/*
 * renders the logo
 */
void render_logo(void)
{

}



/*
 * waits n seconds
 */
void sec_sleep(int n_seconds)
{

	NOT_USED(n_seconds);
}

==> wrogue-0.7.5.tar.bz2: wrogue-0.7.5/src/be_stub.c <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * stub back-end
 */

#define Uses_Ui
#define Uses_DataFile
#define Uses_Util
#include "mheader.h"



/*
 * IO init
 */
void io_init(void)
{

}



/*
 * IO clean up
 */
void io_clean_up(void)
{

}



/*
 * updates the screen
 */
void update_screen(void)
{

}



/*
 * clears the screen
 */
void clear_screen(void)
{

}



/*
 * places the cursor at the specified location
 */
void place_cursor_at(SCREEN_COORD y, SCREEN_COORD x)
{

	NOT_USED(y);
	NOT_USED(x);
}



/*
 * returns the current Y coordinate of the cursor
 */
SCREEN_COORD cursor_y(void)
{
	return 0;
}



/*
 * returns the current X coordinate of the cursor
 */
SCREEN_COORD cursor_x(void)
{

	return 0;
}



/*
 * renders the cursor at its current position
 */
void render_cursor(COLOR color)
{

	NOT_USED(color);
}



/*
 * renders a character at the current cursor position
 */
void render_char(COLOR color, SYMBOL ch)
{

	NOT_USED(color);
	NOT_USED(ch);
}



/*
 * renders a character at the specified position
 */
void render_char_at(COLOR color, SCREEN_COORD y, SCREEN_COORD x, SYMBOL c)
{

	NOT_USED(color);
	NOT_USED(y);
	NOT_USED(x);
	NOT_USED(c);
}



/*
 * get key
 */
KEY_CODE lowlevel_get_key(void)
{

	return 0;
}



/*
 * clears a section of the screen for text display
 */
void clear_text_window(SCREEN_COORD y1, SCREEN_COORD x1, 
	SCREEN_COORD y2, SCREEN_COORD x2
)
{

	NOT_USED(y1);
	NOT_USED(x1);
	NOT_USED(y2);
	NOT_USED(x2);
}



/*
 * renders the background
 */
void render_background(void)
{

}



/*
 * renders the logo
 */
void render_logo(void)
{

}



/*
 * waits n seconds
 */
void sec_sleep(int n_seconds)
{

	NOT_USED(n_seconds);
}
